%% Identification Part
\ProvidesClass{jcaa}[2014/03/21]

%% Initial Code Part
\RequirePackage{ifthen}
\newboolean{ifpreprint}

%% Declaration of Options
\DeclareOption{article}{}
\DeclareOption{proceeding}{}
\DeclareOption{preprint}{\setboolean{ifpreprint}{true} \AtEndOfClass{ \renewcommand{\baselinestretch}{2} \linenumbers \pagestyle{fancy} } }
\DeclareOption{final}{ \AtEndOfClass{ \renewcommand{\baselinestretch}{1} \nolinenumbers \fancypagestyle{plain}{\fancyhf{}} \pagestyle{empty} } }
\DeclareOption{francais}{ \AtEndOfClass{ \renewcommand\Authands{ et } \renewcommand\Authand{ et } \frenchbsetup{IndentFirst=false} } \AtBeginDocument{ \renewcommand\tablenamejcaa{Tableau} \renewcommand\refnamejcaa{R\'ef\'erences} } }
\DeclareOption{english}{}

%% Execution of options
\ExecuteOptions{article,preprint,english}
\ProcessOptions

%% Package loading
\LoadClass[letterpaper,10pt,twocolumn,twoside]{article}
\RequirePackage{graphicx}
\RequirePackage[utf8]{inputenc}
\RequirePackage[tmargin=0.75in,bmargin=0.75in, lmargin=0.75in, rmargin=0.75in]{geometry}
\RequirePackage{times}
\RequirePackage{fancyhdr}
\RequirePackage{authblk}
\RequirePackage{abstract}
\RequirePackage{caption}
\RequirePackage{etoolbox}
\RequirePackage{cite}
\RequirePackage{babel}
\RequirePackage[switch]{lineno}

%% Main Code Part
\setlength{\columnsep}{0.25in}

\setlength{\baselineskip}{12pt}
\setlength{\parskip}{.25\baselineskip}
\setlength{\parindent}{0.25in}

\fancypagestyle{plain}{
	\fancyhf{}
	\fancyfoot[RE,LO]{\fontsize{9pt}{9pt}\selectfont Preprint submitted to Journal of the Canadian Acoustics Association}
	\fancyfoot[RO,LE]{\fontsize{9pt}{9pt}\selectfont \thepage}
	\renewcommand{\headrulewidth}{0pt}
	\renewcommand{\footrulewidth}{0pt}
}

\fancyhf{}
\fancyfoot[RE,LO]{\fontsize{9pt}{9pt}\selectfont Preprint submitted to Journal of the Canadian Acoustics Association}
\fancyfoot[RO,LE]{\fontsize{9pt}{9pt}\selectfont \thepage}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}

\renewcommand\Authfont{\bfseries}
\setlength{\affilsep}{0em}

\def\@maketitle{
\begin{center}
	{\fontsize{14pt}{14pt}\selectfont\bfseries\scshape{\@title} \par}
	\vskip 1em
	{
	\begin{tabular}[t]{c}
		\@author
	\end{tabular}
	\par
	}
\end{center}
\par
}

\renewenvironment{abstract}{
{\vspace{-1em}\begin{center}\fontsize{12pt}{12pt}\selectfont\bfseries {Abstract}\end{center}}\vspace{-.5em}
}{
\vspace{1em}
}

\newenvironment{resume}{
{\vspace{-1em}\begin{center}\fontsize{12pt}{12pt}\selectfont\bfseries {Résumé}\end{center}}\vspace{-.5em}
}{
\vspace{1em}
}

\newenvironment{keyword}{
{\fontsize{10pt}{12pt}\selectfont\bfseries {Keywords: }}
\newcommand{\sep}{\unskip, }
}{
\par \vspace{1em}
}

\newenvironment{motclef}{
{\fontsize{10pt}{12pt}\selectfont\bfseries {Mots clefs: }}
\newcommand{\sep}{\unskip, }
}{
\par \vspace{1em}
}

\renewcommand\section{%
    \@startsection {section}{1}{\z@}%
    {-1.5ex\@plus -1ex \@minus -.2ex}%
    {.5ex}%
    {\fontsize{12pt}{12pt}\selectfont\bfseries}%
}

\renewcommand\subsection{%
    \@startsection{subsection}{2}{\z@}%
    {-1.5ex\@plus -1ex \@minus -.2ex}%
    {.5ex}%
    {\fontsize{11pt}{12pt}\selectfont\bfseries}%
}

\renewcommand\subsubsection{%
    \@startsection{subsubsection}{3}{\z@}%
    {-1.5ex\@plus -1ex \@minus -.2ex}%
    {.5ex}%
    {\fontsize{10pt}{12pt}\selectfont\bfseries}%
}

\setcounter{secnumdepth}{2}

\renewenvironment{figure}[1][]{%
  \@float{figure}[!ht]%
  \centering
}{%
  \end@float
}

\renewenvironment{table}[1][]{%
  \@float{table}[!ht]%
  \centering
}{%
  \end@float
}

\captionsetup{format=plain,labelfont={bf},textfont={normalfont}}
\pretocmd{\@makecaption}{ \fontsize{9pt}{9pt}\selectfont }{}{}

\newcommand\tablenamejcaa{Table}
\def\fnum@table{\tablenamejcaa\nobreakspace\thetable}
\newcommand\figurenamejcaa{Figure}
\def\fnum@figure{\figurenamejcaa\nobreakspace\thefigure}

\newcommand\refnamejcaa{References} 

\renewenvironment{thebibliography}[1]
     {\section*{\refnamejcaa}%
      \@mkboth{\MakeUppercase\refnamejcaa}{\MakeUppercase\refnamejcaa}%
      \fontsize{9pt}{9pt}\selectfont
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
